@@ -1,6 +1,7 @@
 pub mod syntax;
 pub mod compiler;
-pub mod metaschema;
+pub mod support;
+pub mod gen;
 
 #[cfg(test)]
 mod tests {
@@ -30,14 +31,16 @@ mod tests {
 
     #[test]
     fn metaschema_parsing() -> Result<(), std::io::Error> {
-        use preserves::value::{IOValue, Reader};
+        use preserves::value::{BinarySource, IOBinarySource, IOValue, Reader};
         use std::convert::TryFrom;
         use std::convert::From;
+        use crate::gen::schema::*;
 
         let mut f = std::fs::File::open("../../../schema/schema.bin")?;
-        let mut reader = preserves::value::PackedReader::decode_read(&mut f);
+        let mut src = IOBinarySource::new(&mut f);
+        let mut reader = src.packed_iovalues();
         let schema = reader.demand_next(false)?;
-        let parsed = crate::metaschema::Schema::try_from(&schema).expect("successful parse");
+        let parsed = Schema::try_from(&schema).expect("successful parse");
         assert_eq!(schema, IOValue::from(&parsed));
         Ok(())
     }
